@@ -70,7 +70,6 @@ static store_t store[] = {
   { "manual_goto_lon",  STORE_FLOAT,  OFFSET(manual_goto.lon) },
   { "gps_lat",          STORE_FLOAT,  OFFSET(gps.lat) },
   { "gps_lon",          STORE_FLOAT,  OFFSET(gps.lon) },
-  { "load_images",      STORE_BOOL,   OFFSET(load_images) },
   { "search_in",        STORE_INT,    OFFSET(search) },
   { "search_days",      STORE_INT,    OFFSET(search_days) },
   { "search_str",       STORE_STRING, OFFSET(search_str) },
@@ -314,10 +313,9 @@ void gconf_load_state(appdata_t *appdata) {
     appdata->search = SEARCH_NAME | SEARCH_ID;
 
   if(!appdata->image_path) {
-    /* if we get here, there's no config at all yet. So this is a */
-    /* good place to set all kinds of useful defaults */
-    appdata->load_images = TRUE;
 
+    /* use gps by default */
+    appdata->use_gps = TRUE;
 
 #ifndef USE_MAEMO
     char *p = getenv("HOME");
@@ -394,5 +392,15 @@ void gconf_load_state(appdata_t *appdata) {
   if(!appdata->cachelist_items)
     appdata->cachelist_items = CACHELIST_ITEM_DEFAULT;
 
+  /* if there are no entries in the main list, try to add the */
+  /* "welcome" one */
+  if(!appdata->gpx) {
+    char *name = g_strdup(ICONPATH "welcome.gpx");
+    dialog = gpx_busy_dialog_new(GTK_WIDGET(appdata->window));
+    printf("No GPX file loaded, trying to load demo\n");
+    appdata->gpx = gpx_parse(dialog, name);
+    gpx_busy_dialog_destroy(dialog);
+    g_free(name);
+  }
 }
 
