@@ -444,7 +444,7 @@ void mmpoi_export(appdata_t *appdata) {
   label = gtk_label_new(_("Export to:"));
   gtk_box_pack_start(GTK_BOX(hbox), label, TRUE, TRUE,0);
   gtk_misc_set_alignment(GTK_MISC(label), 0.f, 0.5f);
-  GtkWidget *button = gtk_button_new_with_label(_("Browse..."));
+  GtkWidget *button = gtk_button_new_with_label(_("Browse"));
   gtk_signal_connect(GTK_OBJECT(button), "clicked",
 		     GTK_SIGNAL_FUNC(on_browse), (gpointer)&context);
   gtk_box_pack_start(GTK_BOX(hbox), button, FALSE, FALSE,0);
@@ -479,7 +479,7 @@ void mmpoi_export(appdata_t *appdata) {
       GtkWidget *pbar, *wait_dialog = gtk_dialog_new();
       gtk_dialog_set_has_separator(GTK_DIALOG(wait_dialog), FALSE);
       gtk_window_set_default_size(GTK_WINDOW(wait_dialog), 250, 100);
-      gtk_window_set_title(GTK_WINDOW(wait_dialog), _("Exporting..."));
+      gtk_window_set_title(GTK_WINDOW(wait_dialog), _("Exporting"));
       gtk_window_set_modal(GTK_WINDOW(wait_dialog), TRUE);
       gtk_window_set_transient_for(GTK_WINDOW(wait_dialog), 
 				   GTK_WINDOW(context.dialog));
